@@ -36,6 +36,13 @@ elif test -e ../AddressBook/uninstall.sh ; then
 	sh ../AddressBook/uninstall.sh $VENDOR
 fi
 
+# Start WirelessSetup uninstall if found
+if test -e ../wirelessetup/uninstall.sh ; then
+	sh ../wirelessetup/uninstall.sh $VENDOR
+elif test -e ../WirelessSetup/uninstall.sh ; then
+	sh ../WirelessSetup/uninstall.sh $VENDOR
+fi
+
 # Start PSULauncher uninstall if found
 if test -e ../psulauncher/uninstall.sh ; then
 	sh ../psulauncher/uninstall.sh
